| ICTsimSetup | R Documentation |
designs to be passed to
ICTpowerSim, including splitting up the designs over sevar folders
so the simulation can be run in chunks or on multiple computers.ICTsimSetup - function to automate setting up designs to be passed to
ICTpowerSim, including splitting up the designs over sevar folders
so the simulation can be run in chunks or on multiple computers.
ICTsimSetup(
seed,
nL,
phasesL,
propErrVarL,
randFxMeanL,
randFxCorMatL,
randFxVarL,
B = 1000,
nFolders = NULL,
ICTpowerSimOptions = ""
)
seed |
Numeric. A random seed for this simulation. |
nL |
Numeric list. A list of sample sizes. See |
phasesL |
A list of phases. See |
propErrVarL |
Numeric List. See |
randFxMeanL |
A list of effect sizes. See @param randFxCorMatL A list of numeric correlation matrices. See |
randFxVarL |
A list of numeric vectors. See |
nFolders |
Numeric. The number of folders to divide the simulation into.
The default is |
ICTpowerSimOptions |
Character. Other options to be passed to the
function |
muFUN |
Stephen Tueller stueller@rti.org
## Not run:
seed <- 1234
nL <- list(10, 20)
phasesL <- list( makePhase(c(10,10), c(0,1)), makePhase(c(5,15), c(0,1)) )
propErrVarL <- list(.5, .75)
randFxMeanL <- list( list(randFx=list(intercept=0, slope=.25),
fixdFx=list(phase=.5, phaseTime=.25)),
list(randFx=list(intercept=0, slope=.5),
fixdFx=list(phase=.5, phaseTime=.25)))
randFxCorMatL <- list(matrix(c(1,.2,.2,1), 2, 2), matrix(c(1,.6,.6,1), 2, 2))
randFxVarL <- list(c(1, .1), c(1, .2))
B <- 3
nFolders <- 4
ICTpowerSimOptions <-"cores = 4"
ICTsimSetup(seed ,
nL ,
phasesL ,
propErrVarL ,
randFxMeanL ,
randFxCorMatL ,
randFxVarL ,
B ,
nFolders ,
ICTpowerSimOptions)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.