| designICT | R Documentation |
designICT class generatorThe designICT class is a parent class to polyICT and
other future planned classes such as expICT for exponential growth
models and logisticICT for logistic ICT growth models. The
designICT class contains methods (functions common to all child
classes) and fields (variables common to all child classes) and is not
to be used directly.
printA method for printing a the primary inputs for an ICT design.
designCheckThis method simulates one dataset using the current ICT design and
plots average trajectories and histograms of the outcome by phase and
by group. This allows the user to visually check whether the inputs they
provided match their intendend design. The default is to do this with
large samples (N=5,000 per group) to show the asypmtotic behavior. For
comparison, smaller sample sizes can also be used to see the possible
deviations from the population. If smaller sample sizes are used, this
should be repeated several times to prevent over-interpretation of one
sample. See the examples in polyICT.
file Character. A file name for saving the resulting data. The
default is NULL, in which case the data are not saved.
ylim Numeric vector of length 2. Limits for the y-axis. This is
useful when variance is high and/or effect sizes are small, making it
difficult to visualize average change over time. The default is NULL, in
which case default limits are used.
fitMod Logical. Should the model implied by the design be fit to
the simulated data? The default is FALSE.
seed Numeric. A random seed for enabling replication. The default
is 123.
npg Numeric (integer). The number per group. The default is
n=5,000 per group. If a small value is used, the user should repeat the
check with several different seeds. See the examples in
polyICT.
return Character. What should be returned. The default is the
designCheck plot via return='plot'. Other options are 'model'
which returns model fit and descriptive statistics; 'stats' which
returns descriptive statistics only; 'data' which returns the
simulated data; 'datastat' which returns the data and the
descriptive statistics; and 'all' which returns everything in a list.
justData Logical. Should only the data be generated (and not
a model or plot). This speeds up other calls to designCheck, e.g.,
by setupDist.
print()designICT$print(...)
designCheck()designICT$designCheck( file = NULL, ylim = NULL, fitMod = FALSE, seed = 123, npg = 2000, return = "plot", justData = FALSE, type = "histogram", title = "Design Check" )
clone()The objects of this class are cloneable with this method.
designICT$clone(deep = FALSE)
deepWhether to make a deep clone.
Stephen Tueller stueller@rti.org
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.